# TODO:   Function adding single variables in slot taxonTraits
# 
# Author: Miguel Alvarez
################################################################################

add_parent <- function() {
	.Deprecated(msg="'add_parent' is deprecated. Use 'update_concept' instead.")
}

add_trait <- function() {
	.Deprecated(msg="'add_trait' is deprecated. Use 'update_trait' instead.")
}

add_level <- function() {
	.Deprecated(msg=paste("'add_level' is deprecated. Use 'levels' or",
					"'update_concept' instead."))
}

replace_view <- function() {
	.Deprecated(msg=paste("'replace_view' is deprecated. Use",
					"'update_concept' instead."))
}
